/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/
package eu.etaxonomy.taxeditor.editor.group.authority.handler;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.runtime.IProgressMonitor;
import org.eclipse.core.runtime.IStatus;
import org.eclipse.core.runtime.Status;
import org.eclipse.core.runtime.jobs.Job;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.swt.widgets.Display;

import eu.etaxonomy.cdm.model.common.Group;
import eu.etaxonomy.taxeditor.bulkeditor.BulkEditor;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.group.authority.CdmAuthorityEditor;
import eu.etaxonomy.taxeditor.model.LineSelection;
import eu.etaxonomy.taxeditor.model.MessagingUtils;


/**
 * Handler which opens an instance of the {@link CdmAuthorityEditor} for a particluar group.
 * 
 * @author cmathew
 * @created Mar 28, 2013
 *
 */

public class EditCdmAuthoritiesHandler  extends AbstractHandler {

	/* (non-Javadoc)
	 * @see org.eclipse.core.commands.IHandler#execute(org.eclipse.core.commands.ExecutionEvent)
	 */
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		BulkEditor editor = (BulkEditor) EditorUtil.getActiveEditor();
		
		ISelection selection = editor.getSite().getSelectionProvider().getSelection(); 
		if(selection instanceof LineSelection){
		   
			final LineSelection lineSelection = (LineSelection) selection;
			
			Job job = new Job("Opening Cdm Authorities"){

				@Override
				protected IStatus run(IProgressMonitor monitor) {
					monitor.beginTask("Opening Cdm Authorities", lineSelection.size());
					
					for(final Object selectedObject : lineSelection.toArray()){
						if(selectedObject instanceof Group){
							
							Display.getDefault().asyncExec(new Runnable(){

								@Override
								public void run() {								    
									try {
										EditorUtil.openCdmAuthorities(((Group)selectedObject).getUuid());
									} catch (Exception e) {
										MessagingUtils.warningDialog("Could not open CDM Authority Editor", EditorUtil.class, e.getMessage());
									}
								}
								
							});
							monitor.worked(1);
						}
					}
					monitor.done();
					return Status.OK_STATUS;
				}
				
			};
			
			job.setPriority(Job.SHORT);
			job.schedule();			
			
		}
		return null;
	}

}

