/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.name.container;

import java.util.Set;

import org.eclipse.swt.graphics.Font;
import org.eclipse.swt.graphics.Image;

import eu.etaxonomy.cdm.model.name.HomotypicalGroup;
import eu.etaxonomy.cdm.model.name.NomenclaturalStatus;
import eu.etaxonomy.cdm.model.name.NomenclaturalStatusType;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.model.MessagingUtils;
import eu.etaxonomy.taxeditor.preference.Resources;

/**
 * <p>SynonymContainer class.</p>
 *
 * @author p.ciardelli
 * @created 13.01.2009
 * @version 1.0
 */
public class SynonymContainer extends AbstractGroupedContainer<Synonym> {

	private int indent = SYNONYM_INDENT;
	private Image icon = HETEROTYPIC_SYNONYM_ICON;

	/**
	 * <p>Constructor for SynonymContainer.</p>
	 *
	 * @param editor a {@link eu.etaxonomy.taxeditor.editor.name.TaxonNameEditor} object.
	 * @param group a {@link eu.etaxonomy.taxeditor.editor.name.container.AbstractGroup} object.
	 * @param synonym a {@link eu.etaxonomy.cdm.model.taxon.Synonym} object.
	 */
	public SynonymContainer(AbstractHomotypicalGroupContainer group, Synonym synonym) {
		super(synonym);
	}
	
	public SynonymContainer(AbstractHomotypicalGroupContainer group, Synonym synonym, int indent, Image icon){
		super(synonym);
		this.indent = indent;
		this.icon = icon;
	}
	
	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.name.NameComposite#initializeComposite()
	 */
	/** {@inheritDoc} */
	@Override
	protected void initializeComposite() {
		setIsDraggable(true);
		setFont(getViewerFont());
		
		if(getName() == null){
			MessagingUtils.warn(getClass(), "Synonym with a null name detected. This should never happen.");
		}
		
		initTextViewer();
	}
	
	protected void updateIcon(){
		TaxonNameBase name = getName();
		
		if(! name.getStatus().isEmpty()){
			
			Set<NomenclaturalStatus> allStatus = name.getStatus();
			
			for (NomenclaturalStatus status : allStatus){
				if(status.getType() != null && (status.getType().equals(NomenclaturalStatusType.INVALID()) || status.getType().equals(NomenclaturalStatusType.NUDUM()))){
					setIcon(INVALID_OR_NUDUM_NAME_ICON);
					return;
				}
			}
		}
		
		if (isHomotypic()) {
			if(name.isGroupsBasionym()){
				setIcon(HOMOTYPIC_SYNONYM_ORIGINAL_COMBINATION_ICON);
			}else{
				setIcon(HOMOTYPIC_SYNONYM_ICON);
			}
			
			return;
		} else{
			if(name.isGroupsBasionym()){
				setIcon(HETEROTYPIC_SYNONYM_ORIGINAL_COMBINATION_ICON);
				return;
			}
		}	
				
		setIcon(icon);
		
	}
	
	private boolean isHomotypic() {
		HomotypicalGroup group = getSynonym().getHomotypicGroup();
		return group.equals(getEditor().getTaxon().getHomotypicGroup()); 
	}
	
	/**
	 * <p>getSynonym</p>
	 *
	 * @return a {@link eu.etaxonomy.cdm.model.taxon.Synonym} object.
	 */
	public Synonym getSynonym() {
		return getTaxonBase();
	}
		

	/**
	 * <p>getViewerFont</p>
	 *
	 * @return a {@link org.eclipse.swt.graphics.Font} object.
	 */
	protected Font getViewerFont() {
		return EditorUtil.getFont(Resources.SYNONYM_FONT);
	}

	/** {@inheritDoc} */
	@Override
	protected void updateNonEditableInfo() {
		// not needed
	}

	/* (non-Javadoc)
	 * @see eu.etaxonomy.taxeditor.editor.name.AbstractGroupedContainer#updateIndent()
	 */
	@Override
	protected void updateIndent() {		
		setIndent(this.indent );
	}
}
