package eu.etaxonomy.taxeditor.editor.name.handler;

import java.util.UUID;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.core.commands.ExecutionException;
import org.eclipse.core.commands.common.NotDefinedException;
import org.eclipse.core.commands.operations.IUndoContext;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.StructuredSelection;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.handlers.HandlerUtil;

import eu.etaxonomy.cdm.model.common.CdmBase;
import eu.etaxonomy.cdm.model.name.TaxonNameBase;
import eu.etaxonomy.cdm.model.taxon.Synonym;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.cdm.model.taxon.TaxonNode;
import eu.etaxonomy.taxeditor.editor.EditorUtil;
import eu.etaxonomy.taxeditor.editor.MultiPageTaxonEditor;
import eu.etaxonomy.taxeditor.editor.TaxonEditorInput;
import eu.etaxonomy.taxeditor.editor.name.operation.MoveSynonymToAnotherAcceptedTaxonOperation;
import eu.etaxonomy.taxeditor.operation.IPostOperationEnabled;
import eu.etaxonomy.taxeditor.ui.dialog.selection.TaxonNodeSelectionDialog;

public class MoveSynonymToAnotherAcceptedTaxonHandler extends AbstractHandler implements IPostOperationEnabled {
	private static final Logger logger = Logger
	.getLogger(MoveSynonymToAnotherAcceptedTaxonHandler.class);
	private MultiPageTaxonEditor editor;
	
	@Override
	public Object execute(ExecutionEvent event) throws ExecutionException {
		editor =  (MultiPageTaxonEditor) HandlerUtil.getActiveEditor(event);
		Shell shell = HandlerUtil.getActiveShell(event);
		IEditorInput input = editor.getEditorInput();
		if (!EditorUtil.forceUserSave(editor, shell)) {
			return null;
		}
		
		if (!(input instanceof TaxonEditorInput)) {
			logger.error("Editor input is not TaxonEditorInput");
			return null;
		}

		// Get synonym from selection
		StructuredSelection selection = (StructuredSelection) HandlerUtil.getCurrentSelection(event);
		if (!(selection.getFirstElement() instanceof Synonym)) {
			logger.error("Selection does not contain a Synonym");
			return null;
		}

		Synonym synonym = (Synonym) selection.getFirstElement();
		TaxonNode newParentNode = TaxonNodeSelectionDialog.select(HandlerUtil.getActiveShell(event), editor.getConversationHolder(), "Select new accepted taxon", null, null, null);
		Taxon oldParent = ((TaxonEditorInput)input).getTaxon();
	
			MoveSynonymToAnotherAcceptedTaxonOperation operation = new MoveSynonymToAnotherAcceptedTaxonOperation("Change accepted Taxon of Synonym", EditorUtil.getUndoContext(),
					oldParent.getUuid(), synonym.getUuid(), newParentNode.getTaxon(), editor);
			
			EditorUtil.executeOperation(operation);
	

		return null;
	}

	@Override
	public boolean postOperation(CdmBase objectAffectedByOperation) {
		// TODO Auto-generated method stub
		return false;
	}

	@Override
	public boolean onComplete() {
		// TODO Auto-generated method stub
		return false;
	}
	
	

}
