// $Id$
/**
* Copyright (C) 2007 EDIT
* European Distributed Institute of Taxonomy 
* http://www.e-taxonomy.eu
* 
* The contents of this file are subject to the Mozilla Public License Version 1.1
* See LICENSE.TXT at the top of this package for the full license terms.
*/

package eu.etaxonomy.taxeditor.editor.view.descriptive;

import java.util.ArrayList;
import java.util.List;

import org.eclipse.jface.viewers.IStructuredSelection;
import org.eclipse.swt.dnd.DND;
import org.eclipse.swt.dnd.DragSourceAdapter;
import org.eclipse.swt.dnd.DragSourceEvent;

import eu.etaxonomy.cdm.model.description.DescriptionBase;
import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.taxeditor.model.FeatureNodeContainer;

/**
 * @author n.hoffmann
 * @created Feb 8, 2011
 * @version 1.0
 */
public class DescriptionElementDragListener extends DragSourceAdapter {

	private DescriptiveViewPart part;
	
	public DescriptionElementDragListener(DescriptiveViewPart part){
		this.part = part;
	}
	
	/**
	 * Method declared on DragSourceListener
	 */
	public void dragFinished(DragSourceEvent event) {
		if (!event.doit)
			return;
		// FIXME what to do here?
		if (event.detail != DND.DROP_NONE) {
			IStructuredSelection selection = (IStructuredSelection) part.getViewer()
					.getSelection();
			part.changed(null);
		}
	}
	
	/**
	 * Method declared on DragSourceListener
	 */
	public void dragSetData(DragSourceEvent event) {
		IStructuredSelection selection = (IStructuredSelection) part.getViewer()
				.getSelection();
		List<DescriptionElementBase> descriptionElements = new ArrayList<DescriptionElementBase>();
		for (Object object : selection.toList()){
			if(object instanceof DescriptionBase){
				descriptionElements.addAll(((DescriptionBase) object).getElements());
			}else if(object instanceof FeatureNodeContainer){
				descriptionElements.addAll(((FeatureNodeContainer) object).getDescriptionElements());
			}else if(object instanceof DescriptionElementBase){
				descriptionElements.add((DescriptionElementBase)object);
			}
			
		}
		if (DescriptionElementTransfer.getInstance().isSupportedType(
				event.dataType)) {
			event.data = descriptionElements.toArray(new DescriptionElementBase[descriptionElements.size()]);
		}
	}
	
	/**
	 * Method declared on DragSourceListener
	 */
	public void dragStart(DragSourceEvent event) {
		event.doit = !part.getViewer().getSelection().isEmpty();
	}
	
}
