
package eu.etaxonomy.taxeditor.editor.name.operation;

import junit.framework.Assert;

import org.apache.log4j.Logger;
import org.eclipse.core.commands.ExecutionException;
import org.junit.BeforeClass;
import org.junit.Test;

import eu.etaxonomy.cdm.model.description.DescriptionElementBase;
import eu.etaxonomy.cdm.model.description.Feature;
import eu.etaxonomy.cdm.model.description.TaxonDescription;
import eu.etaxonomy.cdm.model.taxon.Taxon;
import eu.etaxonomy.taxeditor.editor.view.descriptive.operation.CreateDescriptionElementOperation;
import eu.etaxonomy.taxeditor.store.operations.AbstractTaxeditorOperationTestBase;

public class CreateDescriptionElementOperationTest extends AbstractTaxeditorOperationTestBase {
	private static final Logger logger = Logger
			.getLogger(CreateDescriptionElementOperationTest.class);


	private static TaxonDescription description;

	private static Feature feature;

	private final DescriptionElementBase[] arrayType = new DescriptionElementBase[0];

	@BeforeClass
	public static void setUpBeforeClass() throws Exception {
		taxon = Taxon.NewInstance(null, null);
		description = TaxonDescription.NewInstance();
		feature = Feature.NewInstance();

		operation = new CreateDescriptionElementOperation("Add Element", null, description, feature, postOperation);
	}


	@Test
	public void testExecute() throws ExecutionException {
		operation.execute(monitor, info);

		Assert.assertTrue(description.getElements().size() > 0);
		Assert.assertEquals(feature, description.getElements().toArray(arrayType)[0].getFeature());
	}

	@Test
	public void testUndo() throws ExecutionException {
		operation.undo(monitor, info);

		Assert.assertTrue(description.getElements().size() == 0);
	}

	@Test
	public void testRedo() throws ExecutionException {
		operation.redo(monitor, info);

		Assert.assertTrue(description.getElements().size() > 0);
		Assert.assertEquals(feature, description.getElements().toArray(arrayType)[0].getFeature());
	}
}
